<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>RestrictVertical</name>
    <message>
        <location filename="../RestrictVerticalInit.js" line="+2"/>
        <source>Restrict &amp;Vertically</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Ograniczenie &amp;pionowo</translatorcomment>
        <translation>Ograniczanie p&amp;ionowo</translation>
    </message>
</context>
</TS>
